Logic restructuring and optimization
====================================

.. toctree::
   :maxdepth: 1
   :caption: Resynthesis

   akers_synthesis
   resyn_engines
   linear_resynthesis
   aqfp_resynthesis

.. toctree::
   :maxdepth: 1
   :caption: Rewriting and resubstitution

   rewrite
   cut_rewriting
   xag_algebraic_rewriting
   mig_algebraic_rewriting
   resubstitution

.. toctree::
   :maxdepth: 1
   :caption: Various optimization algorithms

   xag_optimization
   xmg_optimization
   functional_reduction
   refactoring
   aig_balancing
   xag_balancing
   balancing
   cost_generic_resub